"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _progress = _interopRequireDefault(require("progress"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ci = (0, _utils.getCI)();

class Progress {
  constructor(total, current = 0) {
    this.current = current;
    this.total = total;
    this.percent = 0;
    this.ci = ci.isCi;
    this.format = ':percent (:current/:total images)';
    (0, _utils.log)('');

    if (!this.ci) {
      this.bar = new _progress.default(`[:bar] ${this.format}`, {
        curr: current,
        incomplete: ' ',
        total,
        width: 30
      });
    }

    this.render();
  }

  render() {
    if (!this.ci) {
      this.bar.render();
      return;
    }

    const lastPercent = this.percent;
    this.percent = Math.floor(this.current / this.total * 100);

    if (this.percent !== lastPercent) {
      const msg = this.format.replace(':percent', `${this.percent}%`).replace(':current', this.current).replace(':total', this.total);
      (0, _utils.log)(msg);
    }
  }

  tick() {
    this.current++;

    if (this.ci) {
      this.render();
    } else {
      this.bar.tick();
    }

    if (this.current >= this.total) {
      (0, _utils.log)('');
    }
  }

}

var _default = Progress;
exports.default = _default;