"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.build = build;
exports.default = configure;

var _viswizSdk = _interopRequireDefault(require("viswiz-sdk"));

var _Progress = _interopRequireDefault(require("../Progress"));

var _utils = require("../utils");

var validators = _interopRequireWildcard(require("../validators"));

var _buildResult = require("./build-result");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-console: 0 */
async function build(program, options) {
  if (validators.apiKey(program) || validators.projectID(program)) {
    return;
  }

  const {
    apiKey,
    project: projectID
  } = program;
  const ci = (0, _utils.getCI)();

  if (!options.imageDir) {
    return (0, _utils.error)('Error: Missing image directory!', options);
  }

  if (!options.branch && !ci.branch) {
    return (0, _utils.error)('Error: Missing branch name!', options);
  }

  if (!options.message && !ci.message) {
    return (0, _utils.error)('Error: Missing commit message!', options);
  }

  if (!options.revision && !ci.commit) {
    return (0, _utils.error)('Error: Missing commit revision!', options);
  }

  const client = new _viswizSdk.default(apiKey);
  let progress;
  (0, _utils.log)('Creating build on VisWiz.io...');
  const buildID = await client.buildFolder({
    branch: options.branch || ci.prBranch || ci.branch,
    name: options.message || ci.message,
    projectID,
    revision: options.revision || ci.commit
  }, options.imageDir, (current, total) => {
    if (!progress) {
      progress = new _Progress.default(total, current);
    } else {
      progress.tick();
    }
  }, options.concurrency || 4);
  const url = `https://app.viswiz.io/projects/${projectID}/build/${buildID}/results`;
  (0, _utils.log)('Build created successfully!');
  (0, _utils.log)(`Build report will be available at: ${url}`);

  if (options.waitForResult) {
    await (0, _buildResult.buildResult)(program, {
      build: buildID,
      waitForResult: options.waitForResult
    });
  }

  return 'OK';
}

function configure(program) {
  program.command('build').description('Creates a new build on VisWiz.io and sends images for regression testing.').option('-i, --image-dir <path>', 'The path to a directory (scanned recursively) with images used for the build.').option('-b, --branch [branch name]', 'The branch name for the build. Auto-detected on popular CIs.').option('-m, --message [commit message]', 'The commit message for the build. Auto-detected on popular CIs.').option('-r, --revision [rev]', 'The revision for the build. Auto-detected on popular CIs.').option('-c, --concurrency [number]', 'Determines how many images are uploaded in parallel (defaults to 4).').option('-w, --wait-for-result [timeout]', 'Whether to wait for the result of the build comparison (disabled by default). Waits for a maximum number of seconds (defaults to 600).').action((cmd, options) => build(program, options || cmd).catch(err => {
    (0, _utils.error)(`Error: ${err.message}`);
  }));
}