"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.error = error;
exports.formatTime = formatTime;
exports.getCI = getCI;
exports.log = log;

var _envCi = _interopRequireDefault(require("env-ci"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-console: 0 */
const TEST = process.env.NODE_ENV === 'test';

function error(msg, cmd) {
  log(msg, 'error');
  log('', 'error');

  if (cmd) {
    cmd.outputHelp();
  }

  if (!TEST) {
    process.exit(1);
  }

  return true;
}

function padNumber(value, length = 2) {
  if (TEST && value < 1) {
    value = value * 100;
  }

  return value.toString().padStart(length, '0');
}

function formatTime(time) {
  return `${padNumber(Math.floor(time / 60))}:${padNumber(time % 60)}`;
}

function getCI() {
  const ci = (0, _envCi.default)();
  const messageMap = {
    appveyor: 'APPVEYOR_REPO_COMMIT_MESSAGE',
    bitrise: 'BITRISE_GIT_MESSAGE',
    buildkite: 'BUILDKITE_MESSAGE',
    codeship: 'CI_MESSAGE',
    drone: 'DRONE_COMMIT_MESSAGE',
    shippable: 'COMMIT_MESSAGE',
    travis: 'TRAVIS_COMMIT_MESSAGE'
  };
  ci.message = process.env[messageMap[ci.service]];

  if (!ci.isCi) {
    ci.branch = null;
    ci.commit = null;
  }

  return ci;
}

function log(msg, type = 'log') {
  if (TEST) {
    global.LOGS = global.LOGS || [];
    global.LOGS.push(msg);
    return msg;
  }

  console[type](msg);
}